Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <campbell@blender.org>2022-03-02 06:53:15 +0300
committerCampbell Barton <campbell@blender.org>2022-03-02 06:53:15 +0300
commit426ff481a789017bd5810a2064ec06a298a6f2dc (patch)
treedfe3d7df3c5814d9252847ff5feb718d80c8454c /source/blender/editors/transform/transform.h
parent78372d8b9ca2e923945a009166b9bc04f74ddadf (diff)
Event System: match click-drag & tweak event handling for transform
Diffstat (limited to 'source/blender/editors/transform/transform.h')
-rw-r--r--source/blender/editors/transform/transform.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/source/blender/editors/transform/transform.h b/source/blender/editors/transform/transform.h
index 757c11f1179..3ee5868d5be 100644
--- a/source/blender/editors/transform/transform.h
+++ b/source/blender/editors/transform/transform.h
@@ -592,9 +592,11 @@ typedef struct TransInfo {
/*************** NEW STUFF *********************/
/** event type used to launch transform. */
short launch_event;
- /** Is the actual launch event a tweak event? (launch_event above is set to the corresponding
- * mouse button then.) */
- bool is_launch_event_tweak;
+ /**
+ * Is the actual launch event a drag event?
+ * (`launch_event` is set to the corresponding mouse button then.)
+ */
+ bool is_launch_event_drag;
bool is_orient_default_overwrite;